@@ -89,6 +89,9 @@ class OpenSearchDomain(BaseModel):
         elasticsearch_version: Optional[str],
         elasticsearch_cluster_config: Optional[str],
     ):
+        # Add creation_date attribute
+        self.creation_date = unix_time(datetime.datetime.now())
+
         self.domain_id = f"{account_id}/{domain_name}"
         self.domain_name = domain_name
         self.arn = (
@@ -118,7 +121,8 @@ class OpenSearchDomain(BaseModel):
         self.auto_tune_options = auto_tune_options or {"State": "ENABLE_IN_PROGRESS"}
         if not self.auto_tune_options.get("State"):
             self.auto_tune_options["State"] = "ENABLED"
-        self.off_peak_windows_options = off_peak_window_options
+        # Rename to singular everywhere
+        self.off_peak_window_options = off_peak_window_options
         self.software_update_options = (
             software_update_options or default_software_update_options
         )
@@ -163,7 +167,8 @@ class OpenSearchDomain(BaseModel):
             "DomainEndpointOptions": self.domain_endpoint_options,
             "AdvancedSecurityOptions": self.advanced_security_options,
             "AutoTuneOptions": self.auto_tune_options,
-            "OffPeakWindowsOptions": self.off_peak_windows_options,
+            # Use singular key and attribute
+            "OffPeakWindowOptions": self.off_peak_window_options,
             "SoftwareUpdateOptions": self.software_update_options,
             "ElasticsearchVersion": self.elasticsearch_version,
             "ElasticsearchClusterConfig": self.elasticsearch_cluster_config,
@@ -185,14 +190,95 @@ class OpenSearchDomain(BaseModel):
                 dct[key] = value
         return dct
 
-    def to_config_dict(self) -> Dict[str, Any]:
-        dct = {
-            "EngineVersion": self.engine_version.to_dict(),
+    def _status_block(self) -> Dict[str, Any]:
+        return {
+            "State": "Active",
+            "CreationDate": self.creation_date,
+            "UpdateDate": self.creation_date,
+            "UpdateVersion": 1,
+            "PendingDeletion": False,
         }
-        for key, value in self.dct_options().items():
-            if value is not None:
-                dct[key] = {"Options": value}
-        return dct
+
+    def _wrap(self, options: Any) -> Dict[str, Any]:
+        # Most DomainConfig sections only need {"Options": ...}
+        return {"Options": options}
+
+    def to_config_dict(self) -> Dict[str, Any]:
+        cfg: Dict[str, Any] = {}
+
+        # Cluster config section (key differs for ES vs OS)
+        cluster_key = "ElasticsearchClusterConfig" if self.is_es else "ClusterConfig"
+        cluster_opts = (
+            self.elasticsearch_cluster_config
+            if (self.is_es and self.elasticsearch_cluster_config)
+            else (self.cluster_config or default_cluster_config)
+        )
+        cfg[cluster_key] = self._wrap(cluster_opts)
+
+        # Version section:
+        # - OpenSearch expects Status for EngineVersion (use EngineVersion.to_dict()).
+        # - ES expects only Options for ElasticsearchVersion.
+        if self.is_es:
+            cfg["ElasticsearchVersion"] = self._wrap(
+                self.elasticsearch_version or self.engine_version.options
+            )
+        else:
+            cfg["EngineVersion"] = self.engine_version.to_dict()
+
+        # EBSOptions: default to minimal disabled if not provided
+        ebs_opts = (
+            self.ebs_options if self.ebs_options is not None else {"EBSEnabled": False}
+        )
+        cfg["EBSOptions"] = self._wrap(ebs_opts)
+
+        # Node-to-node encryption: default minimal
+        n2n_opts = (
+            self.node_to_node_encryption_options
+            if self.node_to_node_encryption_options is not None
+            else {"Enabled": False}
+        )
+        cfg["NodeToNodeEncryptionOptions"] = self._wrap(n2n_opts)
+
+        # Encryption at rest: default minimal
+        ear_opts = (
+            self.encryption_at_rest_options
+            if self.encryption_at_rest_options is not None
+            else {"Enabled": False}
+        )
+        cfg["EncryptionAtRestOptions"] = self._wrap(ear_opts)
+
+        # Access policies: default empty string
+        cfg["AccessPolicies"] = self._wrap(self.access_policies or "")
+
+        # Optional passthrough sections
+        if self.snapshot_options is not None:
+            cfg["SnapshotOptions"] = self._wrap(self.snapshot_options)
+        if self.vpc_options is not None:
+            cfg["VPCOptions"] = self._wrap(self.vpc_options)
+        if self.cognito_options is not None:
+            cfg["CognitoOptions"] = self._wrap(self.cognito_options)
+        if self.log_publishing_options is not None:
+            cfg["LogPublishingOptions"] = self._wrap(self.log_publishing_options)
+        if self.auto_tune_options is not None:
+            cfg["AutoTuneOptions"] = self._wrap(self.auto_tune_options)
+        if self.off_peak_window_options is not None:
+            cfg["OffPeakWindowOptions"] = self._wrap(self.off_peak_window_options)
+
+        # Always include with sensible defaults
+        cfg["AdvancedOptions"] = self._wrap(
+            self.advanced_options or default_advanced_options
+        )
+        cfg["DomainEndpointOptions"] = self._wrap(
+            self.domain_endpoint_options or default_domain_endpoint_options
+        )
+        cfg["AdvancedSecurityOptions"] = self._wrap(
+            self.advanced_security_options or default_advanced_security_options
+        )
+        cfg["SoftwareUpdateOptions"] = self._wrap(
+            self.software_update_options or default_software_update_options
+        )
+
+        return cfg
 
     def update(
         self,
@@ -235,8 +321,9 @@ class OpenSearchDomain(BaseModel):
             advanced_security_options or self.advanced_security_options
         )
         self.auto_tune_options = auto_tune_options or self.auto_tune_options
-        self.off_peak_windows_options = (
-            off_peak_window_options or self.off_peak_windows_options
+        # Fix attribute name (singular)
+        self.off_peak_window_options = (
+            off_peak_window_options or self.off_peak_window_options
         )
         self.software_update_options = (
             software_update_options or self.software_update_options
@@ -323,8 +410,9 @@ class OpenSearchServiceBackend(BaseBackend):
             raise ResourceNotFoundException(domain_name)
         return self.domains[domain_name]
 
-    def describe_domain_config(self, domain_name: str) -> OpenSearchDomain:
-        return self.describe_domain(domain_name)
+    def describe_domain_config(self, domain_name: str) -> Dict[str, Any]:
+        domain = self.describe_domain(domain_name)
+        return domain.to_config_dict()
 
     def update_domain_config(
         self,
@@ -344,24 +432,37 @@ class OpenSearchServiceBackend(BaseBackend):
         auto_tune_options: Dict[str, Any],
         off_peak_window_options: Dict[str, Any],
         software_update_options: Dict[str, Any],
-    ) -> OpenSearchDomain:
-        domain = self.describe_domain(domain_name)
-        domain.update(
-            cluster_config=cluster_config,
-            ebs_options=ebs_options,
-            access_policies=access_policies,
-            snapshot_options=snapshot_options,
-            vpc_options=vpc_options,
-            cognito_options=cognito_options,
-            encryption_at_rest_options=encryption_at_rest_options,
-            node_to_node_encryption_options=node_to_node_encryption_options,
-            advanced_options=advanced_options,
-            log_publishing_options=log_publishing_options,
-            domain_endpoint_options=domain_endpoint_options,
-            advanced_security_options=advanced_security_options,
-            auto_tune_options=auto_tune_options,
-            off_peak_window_options=off_peak_window_options,
-            software_update_options=software_update_options,
+    ) -> "OpenSearchDomain":
+        domain = self.domains[domain_name]
+        domain.cluster_config = cluster_config or domain.cluster_config
+        domain.ebs_options = ebs_options or domain.ebs_options
+        domain.access_policies = access_policies or domain.access_policies
+        domain.snapshot_options = snapshot_options or domain.snapshot_options
+        domain.vpc_options = vpc_options or domain.vpc_options
+        domain.cognito_options = cognito_options or domain.cognito_options
+        domain.encryption_at_rest_options = (
+            encryption_at_rest_options or domain.encryption_at_rest_options
+        )
+        domain.node_to_node_encryption_options = (
+            node_to_node_encryption_options or domain.node_to_node_encryption_options
+        )
+        domain.advanced_options = advanced_options or domain.advanced_options
+        domain.log_publishing_options = (
+            log_publishing_options or domain.log_publishing_options
+        )
+        domain.domain_endpoint_options = (
+            domain_endpoint_options or domain.domain_endpoint_options
+        )
+        domain.advanced_security_options = (
+            advanced_security_options or domain.advanced_security_options
+        )
+        domain.auto_tune_options = auto_tune_options or domain.auto_tune_options
+        # Fix attribute name (singular)
+        domain.off_peak_window_options = (
+            off_peak_window_options or domain.off_peak_window_options
+        )
+        domain.software_update_options = (
+            software_update_options or domain.software_update_options
         )
         return domain
 
