@@ -1,15 +1,14 @@
-"""Unit tests for appconfig-supported APIs."""
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_appconfig
+from moto import mock_aws
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
 
 
-@mock_appconfig
+@mock_aws
 def test_create_application():
     client = boto3.client("appconfig", region_name="ap-southeast-1")
     post = client.create_application(Name="testapp", Description="blah")
@@ -39,7 +38,7 @@ def test_create_application():
     assert err["Code"] == "ResourceNotFoundException"
 
 
-@mock_appconfig
+@mock_aws
 def test_tag_application():
     client = boto3.client("appconfig", region_name="us-east-2")
     app_id = client.create_application(Name="testapp")["Id"]
