@@ -2,19 +2,25 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_cloudfront
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from . import cloudfront_test_scaffolding as scaffold
 
 
-@mock_cloudfront
-def test_create_distribution_s3_minimum():
-    client = boto3.client("cloudfront", region_name="us-west-1")
+@mock_aws
+@pytest.mark.parametrize(
+    "region,partition", [("us-west-1", "aws"), ("cn-north-1", "aws-cn")]
+)
+def test_create_distribution_s3_minimum(region, partition):
+    client = boto3.client("cloudfront", region_name=region)
     config = scaffold.example_distribution_config("ref")
 
     dist = client.create_distribution(DistributionConfig=config)["Distribution"]
-    assert dist["ARN"] == f"arn:aws:cloudfront:{ACCOUNT_ID}:distribution/{dist['Id']}"
+    assert (
+        dist["ARN"]
+        == f"arn:{partition}:cloudfront:{ACCOUNT_ID}:distribution/{dist['Id']}"
+    )
     assert dist["Status"] == "InProgress"
     assert "LastModifiedTime" in dist
     assert dist["InProgressInvalidationBatches"] == 0
@@ -109,7 +115,7 @@ def test_create_distribution_s3_minimum():
         "CloudFrontDefaultCertificate": True,
         "IAMCertificateId": "",
         "MinimumProtocolVersion": "TLSv1",
-        "SSLSupportMethod": "",
+        "SSLSupportMethod": "sni-only",
     }
 
     restriction = config["Restrictions"]["GeoRestriction"]
@@ -119,7 +125,7 @@ def test_create_distribution_s3_minimum():
     assert config["WebACLId"] == ""
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_logging():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -141,7 +147,7 @@ def test_create_distribution_with_logging():
     }
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_web_acl():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -153,7 +159,7 @@ def test_create_distribution_with_web_acl():
     assert config["WebACLId"] == "test-web-acl"
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_field_level_encryption_and_real_time_log_config_arn():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -170,7 +176,7 @@ def test_create_distribution_with_field_level_encryption_and_real_time_log_confi
     assert default_cache["RealtimeLogConfigArn"] == real_time_log_config_arn
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_georestriction():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -192,7 +198,7 @@ def test_create_distribution_with_georestriction():
     assert "GB" in restriction["Items"]
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_allowed_methods():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -219,7 +225,7 @@ def test_create_distribution_with_allowed_methods():
     }
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_origins():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.example_distribution_config("ref")
@@ -238,7 +244,27 @@ def test_create_distribution_with_origins():
     assert origin["OriginShield"] == {"Enabled": True, "OriginShieldRegion": "east"}
 
 
-@mock_cloudfront
+@mock_aws
+@pytest.mark.parametrize("nr_of_headers", [1, 2])
+def test_create_distribution_with_custom_headers(nr_of_headers):
+    client = boto3.client("cloudfront", region_name="us-west-1")
+    config = scaffold.example_distribution_config("ref")
+    headers = [
+        {"HeaderName": f"X-Custom-Header{i}", "HeaderValue": f"v{i}"}
+        for i in range(nr_of_headers)
+    ]
+    config["Origins"]["Items"][0]["CustomHeaders"] = {
+        "Quantity": nr_of_headers,
+        "Items": headers,
+    }
+
+    dist = client.create_distribution(DistributionConfig=config)["Distribution"]
+
+    origin = dist["DistributionConfig"]["Origins"]["Items"][0]
+    assert origin["CustomHeaders"] == {"Quantity": nr_of_headers, "Items": headers}
+
+
+@mock_aws
 @pytest.mark.parametrize("compress", [True, False])
 @pytest.mark.parametrize("qs", [True, False])
 @pytest.mark.parametrize("smooth", [True, False])
@@ -280,7 +306,7 @@ def test_create_distribution_with_additional_fields(
     assert forwarded["Cookies"]["WhitelistedNames"]["Items"] == ["x-amz-header"]
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_returns_etag():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -296,7 +322,7 @@ def test_create_distribution_returns_etag():
     )
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_needs_unique_caller_reference():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -325,7 +351,7 @@ def test_create_distribution_needs_unique_caller_reference():
     assert len(resp["Items"]) == 2
 
 
-@mock_cloudfront
+@mock_aws
 def test_get_distribution_config_with_unknown_distribution_id():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -339,7 +365,7 @@ def test_get_distribution_config_with_unknown_distribution_id():
     assert err["Message"] == "The specified distribution does not exist."
 
 
-@mock_cloudfront
+@mock_aws
 def test_get_distribution_config_with_mismatched_originid():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -368,37 +394,7 @@ def test_get_distribution_config_with_mismatched_originid():
     )
 
 
-@mock_cloudfront
-def test_create_origin_without_origin_config():
-    client = boto3.client("cloudfront", region_name="us-west-1")
-
-    with pytest.raises(ClientError) as exc:
-        client.create_distribution(
-            DistributionConfig={
-                "CallerReference": "ref",
-                "Origins": {
-                    "Quantity": 1,
-                    "Items": [{"Id": "origin1", "DomainName": "https://getmoto.org"}],
-                },
-                "DefaultCacheBehavior": {
-                    "TargetOriginId": "origin1",
-                    "ViewerProtocolPolicy": "allow-all",
-                },
-                "Comment": "an optional comment that's not actually optional",
-                "Enabled": False,
-            }
-        )
-
-    metadata = exc.value.response["ResponseMetadata"]
-    assert metadata["HTTPStatusCode"] == 400
-    err = exc.value.response["Error"]
-    assert err["Code"] == "InvalidOrigin"
-    assert (
-        err["Message"] == "The specified origin server does not exist or is not valid."
-    )
-
-
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_with_invalid_s3_bucket():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -435,7 +431,7 @@ def test_create_distribution_with_invalid_s3_bucket():
     )
 
 
-@mock_cloudfront
+@mock_aws
 @pytest.mark.parametrize("ssl_protocols", (["TLSv1"], ["TLSv1", "SSLv3"]))
 def test_create_distribution_custom_config(ssl_protocols):
     client = boto3.client("cloudfront", region_name="us-west-1")
@@ -458,7 +454,7 @@ def test_create_distribution_custom_config(ssl_protocols):
     }
 
 
-@mock_cloudfront
+@mock_aws
 def test_create_distribution_minimal_custom_config():
     client = boto3.client("cloudfront", region_name="us-west-1")
     config = scaffold.minimal_dist_custom_config("ref")
@@ -480,7 +476,7 @@ def test_create_distribution_minimal_custom_config():
     assert custom_config == get_custom_config
 
 
-@mock_cloudfront
+@mock_aws
 def test_list_distributions_without_any():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -492,7 +488,7 @@ def test_list_distributions_without_any():
     assert "Items" not in dlist
 
 
-@mock_cloudfront
+@mock_aws
 def test_list_distributions():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -516,7 +512,7 @@ def test_list_distributions():
     assert item2["Status"] == "Deployed"
 
 
-@mock_cloudfront
+@mock_aws
 def test_get_distribution():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -538,7 +534,7 @@ def test_get_distribution():
     assert config["CallerReference"] == "ref"
 
 
-@mock_cloudfront
+@mock_aws
 def test_get_unknown_distribution():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -553,7 +549,7 @@ def test_get_unknown_distribution():
     assert err["Message"] == "The specified distribution does not exist."
 
 
-@mock_cloudfront
+@mock_aws
 def test_delete_unknown_distribution():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -567,7 +563,7 @@ def test_delete_unknown_distribution():
     assert err["Message"] == "The specified distribution does not exist."
 
 
-@mock_cloudfront
+@mock_aws
 def test_delete_distribution_without_ifmatch():
     client = boto3.client("cloudfront", region_name="us-west-1")
 
@@ -585,7 +581,7 @@ def test_delete_distribution_without_ifmatch():
     )
 
 
-@mock_cloudfront
+@mock_aws
 def test_delete_distribution_random_etag():
     """
     Etag validation is not implemented yet
@@ -606,7 +602,7 @@ def test_delete_distribution_random_etag():
     assert err["Code"] == "NoSuchDistribution"
 
 
-@mock_cloudfront
+@mock_aws
 def test_get_distribution_config():
     client = boto3.client("cloudfront", region_name="us-east-1")
 
@@ -691,3 +687,88 @@ def test_get_distribution_config():
     }
 
     assert config["WebACLId"] == ""
+
+
+@mock_aws
+def test_add_new_gateway_basic():
+    # Setup
+    cloudfront_client_mock = boto3.client("cloudfront", region_name="us-east-1")
+    config = scaffold.example_distribution_config("ref")
+    distribution_id = cloudfront_client_mock.create_distribution(
+        DistributionConfig=config
+    )["Distribution"]["Id"]
+    existing_config = cloudfront_client_mock.get_distribution(Id=distribution_id)[
+        "Distribution"
+    ]["DistributionConfig"]
+    new_behaviors = [
+        {
+            "PathPattern": "bla/*",
+            "TargetOriginId": "test.invalid",
+            "ViewerProtocolPolicy": "redirect-to-https",
+            "AllowedMethods": {
+                "Quantity": 7,
+                "Items": ["GET", "HEAD", "OPTIONS", "PUT", "POST", "PATCH", "DELETE"],
+                "CachedMethods": {"Quantity": 2, "Items": ["GET", "HEAD"]},
+            },
+            "SmoothStreaming": False,
+            "Compress": False,
+            "LambdaFunctionAssociations": {"Quantity": 0},
+            "FieldLevelEncryptionId": "",
+            "CachePolicyId": "4135ea2d-6df8-44a3-9df3-4b5a84be39ad",  # CachingDisabled
+            "OriginRequestPolicyId": "b689b0a8-53d0-40ab-baf2-68738e2966ac",  # AllViewerExceptHostHeader
+        }
+    ]
+
+    new_config = existing_config
+    new_config["CacheBehaviors"]["Quantity"] = 1
+    new_config["CacheBehaviors"]["Items"] = new_behaviors
+
+    # Execute
+    cloudfront_client_mock.update_distribution(
+        DistributionConfig=new_config, Id=distribution_id, IfMatch="1"
+    )
+    result = cloudfront_client_mock.get_distribution(Id=distribution_id)[
+        "Distribution"
+    ]["DistributionConfig"]
+
+    # Verify
+    assert result["CacheBehaviors"]["Quantity"] == 1
+    assert (
+        result["CacheBehaviors"]["Items"][0]["PathPattern"]
+        == new_behaviors[0]["PathPattern"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["TargetOriginId"]
+        == new_behaviors[0]["TargetOriginId"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["ViewerProtocolPolicy"]
+        == new_behaviors[0]["ViewerProtocolPolicy"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["AllowedMethods"]
+        == new_behaviors[0]["AllowedMethods"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["SmoothStreaming"]
+        == new_behaviors[0]["SmoothStreaming"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["Compress"] == new_behaviors[0]["Compress"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["LambdaFunctionAssociations"]["Quantity"]
+        == new_behaviors[0]["LambdaFunctionAssociations"]["Quantity"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["FieldLevelEncryptionId"]
+        == new_behaviors[0]["FieldLevelEncryptionId"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["CachePolicyId"]
+        == new_behaviors[0]["CachePolicyId"]
+    )
+    assert (
+        result["CacheBehaviors"]["Items"][0]["OriginRequestPolicyId"]
+        == new_behaviors[0]["OriginRequestPolicyId"]
+    )
