@@ -1,10 +1,12 @@
 import boto3
+import pytest
 
-from moto import mock_ec2, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from tests.test_ec2 import ec2_aws_verified
 
 
-@mock_ec2
+@mock_aws
 def test_create():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     prefix_list = ec2.create_managed_prefix_list(
@@ -24,7 +26,7 @@ def test_create():
     assert prefix_list["OwnerId"] == ACCOUNT_ID
 
 
-@mock_ec2
+@mock_aws
 def test_create_with_tags():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     prefix_list = ec2.create_managed_prefix_list(
@@ -41,28 +43,30 @@ def test_create_with_tags():
     assert prefix_list["Tags"] == [{"Key": "key1", "Value": "val1"}]
 
 
-@mock_ec2
-def test_describe_managed_prefix_lists():
-    ec2 = boto3.client("ec2", region_name="us-west-1")
+@pytest.mark.aws_verified
+@ec2_aws_verified(create_vpc=False, create_sg=False)
+def test_describe_managed_prefix_lists(ec2_client=None):
+    ec2 = ec2_client
 
     prefix_list = ec2.create_managed_prefix_list(
-        PrefixListName="examplelist", MaxEntries=2, AddressFamily="?"
+        PrefixListName="examplelist", MaxEntries=2, AddressFamily="IPv4"
     )
     pl_id = prefix_list["PrefixList"]["PrefixListId"]
 
     all_lists = ec2.describe_managed_prefix_lists()["PrefixLists"]
     assert pl_id in [pl["PrefixListId"] for pl in all_lists]
-    assert set([pl["OwnerId"] for pl in all_lists]) == {"aws", ACCOUNT_ID}
+    assert all("StateMessage" not in pl for pl in all_lists)
+    assert "AWS" in [pl["OwnerId"] for pl in all_lists]
 
 
-@mock_ec2
+@mock_aws
 def test_describe_managed_prefix_lists_with_prefix():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
     default_lists = ec2.describe_managed_prefix_lists()["PrefixLists"]
     if not settings.TEST_SERVER_MODE:
         # ServerMode is not guaranteed to only have AWS prefix lists
-        assert set([pl["OwnerId"] for pl in default_lists]) == {"aws"}
+        assert set([pl["OwnerId"] for pl in default_lists]) == {"AWS"}
 
     random_list_id = default_lists[0]["PrefixListId"]
 
@@ -71,10 +75,10 @@ def test_describe_managed_prefix_lists_with_prefix():
     ]
     assert len(lists_by_id) == 1
     if not settings.TEST_SERVER_MODE:
-        assert lists_by_id[0]["OwnerId"] == "aws"
+        assert lists_by_id[0]["OwnerId"] == "AWS"
 
 
-@mock_ec2
+@mock_aws
 def test_describe_managed_prefix_lists_with_tags():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
@@ -99,7 +103,7 @@ def test_describe_managed_prefix_lists_with_tags():
     assert untagged_pl_id not in [pl["PrefixListId"] for pl in tagged_lists]
 
 
-@mock_ec2
+@mock_aws
 def test_get_managed_prefix_list_entries():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     resp = ec2.create_managed_prefix_list(
@@ -130,7 +134,7 @@ def test_get_managed_prefix_list_entries():
     assert {"Cidr": "10.0.0.2", "Description": "entry2"} in entries
 
 
-@mock_ec2
+@mock_aws
 def test_get_managed_prefix_list_entries_0_entries():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     resp = ec2.create_managed_prefix_list(
@@ -144,7 +148,7 @@ def test_get_managed_prefix_list_entries_0_entries():
     assert entries == []
 
 
-@mock_ec2
+@mock_aws
 def test_delete_managed_prefix_list():
     ec2 = boto3.client("ec2", region_name="us-west-1")
     id1 = ec2.create_managed_prefix_list(
@@ -172,7 +176,7 @@ def test_delete_managed_prefix_list():
     }
 
 
-@mock_ec2
+@mock_aws
 def test_describe_prefix_lists():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
@@ -189,7 +193,7 @@ def test_describe_prefix_lists():
         assert "com.amazonaws" in pl["PrefixListName"]
 
 
-@mock_ec2
+@mock_aws
 def test_modify_manage_prefix_list():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
@@ -228,7 +232,7 @@ def test_modify_manage_prefix_list():
     assert {"Cidr": "10.0.0.2", "Description": "entry2"} not in entries
 
 
-@mock_ec2
+@mock_aws
 def test_modify_manage_prefix_list_add_to_empty_list():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
@@ -260,7 +264,7 @@ def test_modify_manage_prefix_list_add_to_empty_list():
     assert {"Cidr": "10.0.0.2", "Description": "entry2"} not in entries
 
 
-@mock_ec2
+@mock_aws
 def test_modify_manage_prefix_list_name_only():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
@@ -283,7 +287,7 @@ def test_modify_manage_prefix_list_name_only():
     assert described == prefix_list
 
 
-@mock_ec2
+@mock_aws
 def test_modify_manage_prefix_list_specifying_version():
     ec2 = boto3.client("ec2", region_name="us-west-1")
 
