@@ -1,14 +1,14 @@
 import json
 
 import moto.server as server
-from moto import mock_mediastore
+from moto import mock_aws
 
 """
 Test the different server responses
 """
 
 
-@mock_mediastore
+@mock_aws
 def test_mediastore_lists_containers():
     backend = server.create_backend_app("mediastore")
     test_client = backend.test_client()
