@@ -2,10 +2,10 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_sdb
+from moto import mock_aws
 
 
-@mock_sdb
+@mock_aws
 @pytest.mark.parametrize("name", ["", "a", "a#", "aaa#", "as@asdff", "asf'qwer"])
 def test_create_domain_invalid(name):
     # Error handling is always the same
@@ -18,7 +18,7 @@ def test_create_domain_invalid(name):
     assert "BoxUsage" in err
 
 
-@mock_sdb
+@mock_aws
 @pytest.mark.parametrize(
     "name", ["abc", "ABc", "a00", "as-df", "jk_kl", "qw.rt", "asfljaejadslfsl"]
 )
@@ -28,7 +28,7 @@ def test_create_domain_valid(name):
     sdb.create_domain(DomainName=name)
 
 
-@mock_sdb
+@mock_aws
 def test_create_domain_and_list():
     sdb = boto3.client("sdb", region_name="eu-west-1")
     sdb.create_domain(DomainName="mydomain")
@@ -37,7 +37,7 @@ def test_create_domain_and_list():
     assert all_domains == ["mydomain"]
 
 
-@mock_sdb
+@mock_aws
 def test_delete_domain():
     sdb = boto3.client("sdb", region_name="eu-west-1")
     sdb.create_domain(DomainName="mydomain")
@@ -47,7 +47,7 @@ def test_delete_domain():
     assert "DomainNames" not in all_domains
 
 
-@mock_sdb
+@mock_aws
 def test_delete_domain_unknown():
     sdb = boto3.client("sdb", region_name="eu-west-1")
     sdb.delete_domain(DomainName="unknown")
@@ -56,7 +56,7 @@ def test_delete_domain_unknown():
     assert "DomainNames" not in all_domains
 
 
-@mock_sdb
+@mock_aws
 def test_delete_domain_invalid():
     sdb = boto3.client("sdb", region_name="eu-west-1")
     with pytest.raises(ClientError) as exc:
